serverpod_auth_idp_flutter_facebook library
Provides Facebook-specific authentication functionality for the Serverpod authentication module.
Classes
- FacebookAuthController
- Controller for managing Facebook-based authentication flows.
- FacebookSignInButton
- A styled button for Facebook Sign-In.
- FacebookSignInService
- Service to manage Facebook Sign-In and ensure it is only initialized once throughout the app lifetime.
- FacebookSignInStyle
- The style of the rendered Facebook button.
- FacebookSignInWidget
- A widget that provides Facebook Sign-In functionality for all platforms.
Enums
- FacebookAuthState
- Represents the state of the Facebook authentication flow.
- FacebookButtonLogoAlignment
- The alignment of the Facebook logo. The default value is left.
- FacebookButtonShape
- The shape of the Facebook Sign-In button.
- FacebookButtonSize
- The size of the Facebook Sign-In button.
- FacebookButtonStyle
- The style of Facebook Sign-In button.
- FacebookButtonText
- The type of Facebook Sign-In button.
Extensions
- FacebookSignInExtension on FlutterAuthSessionManager
-
Expose convenient methods on
FlutterAuthSessionManager.
Exceptions / Errors
- FacebookLimitedAccessTokenException
- Exception thrown when a limited access token is received from Facebook.